@@ -6,8 +6,8 @@
 /**
  * @file api/v1/announcements/index.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2003-2019 John Willinsky
+ * Copyright (c) 2023 Simon Fraser University
+ * Copyright (c) 2023 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_announcements
@@ -15,4 +15,4 @@
  * @brief Handle API requests for announcements.
  */
 
-return new \PKP\API\v1\announcements\PKPAnnouncementHandler();
+return new \PKP\handler\APIHandler(new \PKP\API\v1\announcements\PKPAnnouncementController());
