@@ -21,16 +21,16 @@ namespace APP\search;
 
 use APP\core\Application;
 use APP\core\Request;
-use APP\core\Services;
 use APP\facades\Repo;
 use APP\server\Server;
+use PKP\controlledVocab\ControlledVocab;
 use PKP\db\DAORegistry;
 use PKP\facades\Locale;
 use PKP\plugins\Hook;
 use PKP\search\SubmissionSearch;
 use PKP\submission\PKPSubmission;
-use PKP\submission\SubmissionKeywordDAO;
 use PKP\user\User;
+use PKP\userGroup\UserGroup;
 
 class PreprintSearch extends SubmissionSearch
 {
@@ -74,14 +74,15 @@ class PreprintSearch extends SubmissionSearch
                 $filter['dateStart'] = $oneMonthAgo;
                 $filter['dateEnd'] = $today;
             }
-            $rawReport = Services::get('publicationStats')->getTotals($filter);
+            $rawReport = app()->get('publicationStats')->getTotals($filter);
             foreach ($rawReport as $row) {
                 $unorderedResults[$row->submission_id]['metric'] = $row->metric;
             }
         }
 
         $i = 0; // Used to prevent ties from clobbering each other
-        $authorUserGroups = Repo::userGroup()->getCollector()->filterByRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])->getMany();
+        $authorUserGroups = UserGroup::withRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])
+            ->get();
         foreach ($unorderedResults as $submissionId => $data) {
             // Exclude unwanted IDs.
             if (in_array($submissionId, $exclude)) {
@@ -303,6 +304,8 @@ class PreprintSearch extends SubmissionSearch
      *
      * @return null|array An array of string keywords or null
      * if some kind of error occurred.
+     *
+     * @hook PreprintSearch::getSimilarityTerms [[$submissionId, &$searchTerms]]
      */
     public function getSimilarityTerms($submissionId)
     {
@@ -317,9 +320,14 @@ class PreprintSearch extends SubmissionSearch
             $preprint = Repo::submission()->get($submissionId);
             if ($preprint->getData('status') === PKPSubmission::STATUS_PUBLISHED) {
                 // Retrieve keywords (if any).
-                /** @var SubmissionKeywordDAO */
-                $submissionSubjectDao = DAORegistry::getDAO('SubmissionKeywordDAO');
-                $allSearchTerms = array_filter($submissionSubjectDao->getKeywords($preprint->getId(), [Locale::getLocale(), $preprint->getLocale(), Locale::getPrimaryLocale()]));
+                $allSearchTerms = array_filter(
+                    Repo::controlledVocab()->getBySymbolic(
+                        ControlledVocab::CONTROLLED_VOCAB_SUBMISSION_KEYWORD,
+                        Application::ASSOC_TYPE_PUBLICATION,
+                        $preprint->getId(),
+                        [Locale::getLocale(), $preprint->getData('locale'), Locale::getPrimaryLocale()]
+                    )
+                );
                 foreach ($allSearchTerms as $locale => $localeSearchTerms) {
                     $searchTerms += $localeSearchTerms;
                 }
@@ -346,6 +354,8 @@ class PreprintSearch extends SubmissionSearch
 
     /**
      * See SubmissionSearch::getResultSetOrderingOptions()
+     *
+     * @hook SubmissionSearch::getResultSetOrderingOptions [[$context, &$resultSetOrderingOptions]]
      */
     public function getResultSetOrderingOptions($request)
     {
@@ -395,7 +405,3 @@ class PreprintSearch extends SubmissionSearch
         return DAORegistry::getDAO('PreprintSearchDAO');
     }
 }
-
-if (!PKP_STRICT_MODE) {
-    class_alias('\APP\search\PreprintSearch', '\PreprintSearch');
-}
