@@ -108,6 +108,12 @@ class CrossrefExportPlugin extends DOIPubIdExportPlugin
      */
     public function getStatusMessage($request)
     {
+        // Application is set to sandbox mode and will not run the features of plugin
+        if (Config::getVar('general', 'sandbox', false)) {
+            error_log('Application is set to sandbox mode and will not have any interaction with crossref external service');
+            return __('common.sandbox');
+        }
+
         // if the failure occurred on request and the message was saved
         // return that message
         $submissionId = $request->getUserVar('submissionId');
@@ -341,6 +347,12 @@ class CrossrefExportPlugin extends DOIPubIdExportPlugin
      */
     public function depositXML($object, $context, $filename)
     {
+        // Application is set to sandbox mode and will not run the features of plugin
+        if (Config::getVar('general', 'sandbox', false)) {
+            error_log('Application is set to sandbox mode and will not have any interaction with crossref external service');
+            return false;
+        }
+
         $status = null;
         $msgSave = null;
 
@@ -379,7 +391,7 @@ class CrossrefExportPlugin extends DOIPubIdExportPlugin
                 $eResponseBody = $e->getResponse()->getBody();
                 $eStatusCode = $e->getResponse()->getStatusCode();
                 if ($eStatusCode == static::CROSSREF_API_DEPOSIT_ERROR_FROM_CROSSREF) {
-                    $xmlDoc = new DOMDocument();
+                    $xmlDoc = new DOMDocument('1.0', 'utf-8');
                     $xmlDoc->loadXML($eResponseBody);
                     $batchIdNode = $xmlDoc->getElementsByTagName('batch_id')->item(0);
                     $msg = $xmlDoc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -396,7 +408,7 @@ class CrossrefExportPlugin extends DOIPubIdExportPlugin
         }
 
         // Get DOMDocument from the response XML string
-        $xmlDoc = new DOMDocument();
+        $xmlDoc = new DOMDocument('1.0', 'utf-8');
         $xmlDoc->loadXML($response->getBody());
         $batchIdNode = $xmlDoc->getElementsByTagName('batch_id')->item(0);
         $submissionIdNode = $xmlDoc->getElementsByTagName('submission_id')->item(0);
